==> camitk_3.4.0.orig.tar.gz: camitk-3.4.0-Source/sdk/actions/mesh/meshprocessing/MeshProcessingExtension.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#include "MeshProcessingExtension.h"
#include "Decimation.h"
#include "CleanPolyData.h"
#include "FillWithPoints.h"
#include "WarpOut.h"
#include "ExtractSurface.h"
#include "ICPRegistration.h"
#include "InvertMesh.h"
#include "SmoothFilter.h"
#include "ExtractEdges.h"
#include "MergeMeshs.h"
#include "MeshClipping.h"
#include "ComputeCurvatures.h"
#include "LoadTransformation.h"
#include "ExportAsMDL.h"
#include "LoadTextureFromBMP.h"
#include "SaveDisplacementFromTransformation.h"

#include "Application.h"

// --------------- declare the extension -------------------
Q_EXPORT_PLUGIN2(processing, MeshProcessingExtension)

// -------------------- init --------------------
void MeshProcessingExtension::init() {
    registerNewAction(Decimation);
    registerNewAction(CleanPolyData);
    registerNewAction(FillWithPoints);
    registerNewAction(WarpOut);
    registerNewAction(ExtractSurface);
    registerNewAction(ICPRegistration);
    registerNewAction(InvertMesh);
    registerNewAction(SmoothFilter);
    registerNewAction(ExtractEdges);
    registerNewAction(MergeMeshs);
    registerNewAction(MeshClipping);
    registerNewAction(ComputeCurvatures);
    registerNewAction(LoadTransformation);
    registerNewAction(ExportAsMDL);
    registerNewAction(LoadTextureFromBMP);
    registerNewAction(SaveDisplacementFromTransformation);
}

==> camitk_4.0.4.orig.tar.gz: camitk-4.0.4-Source/sdk/actions/mesh/meshprocessing/MeshProcessingExtension.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#include "MeshProcessingExtension.h"
#include "Decimation.h"
#include "CleanPolyData.h"
#include "FillWithPoints.h"
#include "WarpOut.h"
#include "ExtractSurface.h"
#include "ICPRegistration.h"
#include "InvertMesh.h"
#include "SmoothFilter.h"
#include "ExtractEdges.h"
#include "MergeMeshs.h"
#include "MeshClipping.h"
#include "ComputeCurvatures.h"
#include "LoadTransformation.h"
#include "ExportAsMDL.h"
#include "LoadTextureFromBMP.h"
#include "SaveDisplacementFromTransformation.h"
#include "AppendMeshes.h"

#include "Application.h"

// -------------------- init --------------------
void MeshProcessingExtension::init() {
    registerNewAction ( Decimation );
    registerNewAction ( CleanPolyData );
    registerNewAction ( FillWithPoints );
    registerNewAction ( WarpOut );
    registerNewAction ( ExtractSurface );
    registerNewAction ( ICPRegistration );
    registerNewAction ( InvertMesh );
    registerNewAction ( SmoothFilter );
    registerNewAction ( ExtractEdges );
    registerNewAction ( MergeMeshs );
    registerNewAction ( MeshClipping );
    registerNewAction ( ComputeCurvatures );
    registerNewAction ( LoadTransformation );
    registerNewAction ( ExportAsMDL );
    registerNewAction ( LoadTextureFromBMP );
    registerNewAction ( SaveDisplacementFromTransformation );
    registerNewAction ( AppendMeshes );
}
